@@ -1,11 +1,4 @@
-# -*- coding: future_fstrings -*-
-#####################################################################
-### Rohde & Schwarz Automation for demonstration use.
-###
-### Title : Common file functions
-### Author: Martin C Lim
-### Date  : 2018.02.01
-#####################################################################
+"""Common file functions"""
 from datetime  import datetime
 import os
 
@@ -66,7 +59,7 @@ class FileIO(object):
 
     def write(self,inStr):
         if self.debug: print("FileOut    : %s"%inStr)
-        sDate = datetime.now().strftime("%y%m%d-%H:%M:%S.%f") #Date String
+        sDate = datetime.now().strftime("%y%m%d-%H:%M:%S.%f")   #Date String
         with open(self.sFName, 'a') as csv_file:
             csv_file.write(f'{sDate},{inStr}\n')
 
@@ -81,7 +74,7 @@ class FileIO(object):
 if __name__ == "__main__":
     ### this won't be run when imported
     FileIO = FileIO()
-    FileIO.Init("FileIO.csv")
+    FileIO.init("FileIO.csv")
     FileIO.write("Hello World")
     FileIO.write_raw("Hello Worldd")
     data = FileIO.readcsv()
