@@ -1,22 +1,9 @@
 """
-OTA ATS1800; ATS1500 support
- _____  _____   ____ _______ ____ _________     _______  ______
-|  __ ||  __ | / __ |__   __/ __ |__   __| |   / /  __ ||  ____|
-| |__) | |__) | |  | | | | | |  | | | |   | |_/ /| |__) | |__
-|  ___/|  _  /| |  | | | | | |  | | | |    |   / |  ___/|  __|
-| |    | | | || |__| | | | | |__| | | |     | |  | |    | |____
-|_|    |_|  |_||____/  |_|  |____/  |_|     |_|  |_|    |______|
-                        _            _           _
-                       | |          | |         | |
-            _   _ _ __ | |_ ___  ___| |_ ___  __| |
-           | | | | '_ || __/ _ |/ __| __/ _ |/ _` |
-           | |_| | | | | ||  __/|__ | ||  __/ (_| |
-            |__,_|_| |_||__|___||___/|__|___||__,_|
-
-Terms:  Azimuth:    Θθ; Theta; Turntable;
-        Elevation:  Φφ; Phi; Cradle;
-OTA:    ATS1500     Az over El;
-        ATS1800     Az over El;
+Terms:  Azimuth:    Θθ; Theta; Turntable
+        Elevation:  Φφ; Phi; Cradle
+OTA:    ATS000      Az over El
+        ATS1500     Az over El
+        ATS1800     Az over El
 """
 from rssd.OTA.Common     import OTA           #pylint: disable=E0611,E0401
 
@@ -95,6 +82,7 @@ class OTA(OTA):
 ###############################################################################
 if __name__ == "__main__":
     # http://169.254.2.10/Tc3PlcHmiWeb/Port_851/Visu/webvisu.htm
-    ATS1800 = OTA()
-    ATS1800.jav_Open('169.254.2.10',port=200)
-    print(ATS1800.Get_IDN())
+    ATS1800 = OTA().open('169.254.2.10', type = 'socket', param = 200)
+    ATS1800.Set_ElevateAngle(40)
+    print(ATS1800.Get_ElevateRunning())
+    print(ATS1800.Get_ElevateAngle())
