@@ -1,10 +1,6 @@
-# -*- coding: future_fstrings -*-
-################################################################################
-### Rohde & Schwarz Automation for demonstration use.
-### Purpose: Radio Communication Tester(RCT) Functions
-### Author : Martin C Lim
-################################################################################
-from rssd.RCT.Common import RCT                                                 #pylint: disable=E0611,E0401
+""" Radio Communication Tester(RCT) Functions"""
+#pylint: disable=E0611,E0401
+from rssd.RCT.Common import RCT
 
 class RCT(RCT):
     """ Rohde & Schwarz Radio Comm Tester Object """
@@ -82,59 +78,59 @@ class RCT(RCT):
 
     def Get_5GNR_BWP_Ch_DMRS_AddPosition(self):
         """ 0 to 3 """
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:BWP:PUSC:DMTA?  BWP{self.BWP}').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:BWP:PUSC:DMTA?  BWP{self.BWP}')
         return rdStr[1]
 
     def Get_5GNR_BWP_Ch_DMRS_Antenna(self):
         """ 1 to 0 """
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:ADD?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:ADD?')
         return rdStr[3]
 
     def Get_5GNR_BWP_Ch_DMRS_CDMGroup(self):
         """ 1 to 3 """
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:ADD?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:ADD?')
         return rdStr[1]
 
     def Get_5GNR_BWP_Ch_DMRS_Config(self):
         """ 1 to 2 """
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:BWP:PUSC:DMTA? BWP{self.BWP}').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:BWP:PUSC:DMTA? BWP{self.BWP}')
         return rdStr[0]
 
     def Get_5GNR_BWP_Ch_DMRS_Mapping(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?')
         return rdStr[0]
 
     def Get_5GNR_BWP_Ch_DMRS_MSymbLen(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:ADD?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:ADD?')
         return rdStr[0]
 
     def Get_5GNR_BWP_Ch_DMRS_RelPwr(self):
         """ -10 to 10 """
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:ADD?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:ADD?')
         return rdStr[2]
 
     def Get_5GNR_BWP_Ch_DMRS_SeqGenMeth(self):
         """CellID DMRS"""
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:SGEN?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:SGEN?')
         return rdStr[0]
 
     def Get_5GNR_BWP_Ch_DMRS_SeqGenSeed(self):
         """ 0 to 655535 """
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:SGEN?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:SGEN?')
         return rdStr[1]
 
     def Get_5GNR_BWP_Ch_DMRS_SeqGen_n_SCID(self):
         """ 0 to 1 """
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:SGEN?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC:SGEN?')
         return rdStr[2]
 
     def Get_5GNR_BWP_Ch_Modulation(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?')
         return rdStr[5]
 
     def Get_5GNR_BWP_Ch_Mapping(self):
         """PUSCH Mapping"""
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?')
         return rdStr[0]
 
     def Get_5GNR_BWP_Ch_PTRS_K(self):
@@ -162,19 +158,19 @@ class RCT(RCT):
 
     def Get_5GNR_BWP_Ch_ResBlock(self):
         ### RB = (CHBw * 0.95) / (SubSp * 12)
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?')
         return rdStr[3]
 
     def Get_5GNR_BWP_Ch_ResBlockOffset(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?')
         return rdStr[4]
 
     def Get_5GNR_BWP_Ch_SymbNum(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?')
         return rdStr[1]
 
     def Get_5GNR_BWP_Ch_SymbOff(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:ALL{self.alloc}:PUSC?')
         return rdStr[2]
 
     def Get_5GNR_BWP_Count(self):
@@ -183,20 +179,15 @@ class RCT(RCT):
 
     def Get_5GNR_BWP_ResBlock(self):
         ### RB = (CHBw * 0.95) / (SubSp * 12)
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:BWP? BWP{self.BWP}').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:BWP? BWP{self.BWP}')
         return rdStr[2]
 
     def Get_5GNR_BWP_ResBlockOffset(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:BWP? BWP{self.BWP}').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:BWP? BWP{self.BWP}')
         return rdStr[3]
 
-    # def Get_5GNR_BWP_SlotNum(self):
-    #     ### Number of slots
-    #     rdStr = self.query(f':SOUR1:BB:NR5G:SCH:CELL{self.cc}:SUBF{self.subF}:USER0:BWP0:ALL{self.alloc}:SLOT?')
-    #     return rdStr
-
     def Get_5GNR_BWP_SubSpace(self):
-        rdStr = self.query(f'CONF:NRMM:MEAS:CC{self.cc}:BWP? BWP{self.BWP}').split(',')
+        rdStr = self.queryFloatArry(f'CONF:NRMM:MEAS:CC{self.cc}:BWP? BWP{self.BWP}')
         return rdStr[0]
 
     def Get_5GNR_CC_Offset(self):
@@ -245,14 +236,12 @@ class RCT(RCT):
         rdStr = '<notRead>'
         return rdStr
 
-
-    def Get_5GNR_Params(self,amp,swp,sys,trc,header=0):                 #pylint: disable=R0913
+    def Get_5GNR_Params(self,amp,swp,sys,header=0):                 #pylint: disable=R0913
         """Amp,Sweep,System,Trace"""
         outStr = ""
         outStr += self.Get_5GNR_Params_Amp(header)+","   if (amp==1) else ""
         outStr += self.Get_5GNR_Params_Sweep(header)+"," if (swp==1) else ""
         outStr += self.Get_5GNR_Params_System(header)+","if (sys==1) else ""
-        outStr += self.Get_5GNR_Params_Trace(header)+"," if (trc==1) else ""
         return outStr
 
     def Get_5GNR_Params_Amp(self,header=0):
@@ -269,7 +258,7 @@ class RCT(RCT):
     def Get_5GNR_Params_Sweep(self,header=0):
         # SwpTime,SwpPts,SwpType,SwpOpt,
         if header != 1:
-            Time    = '<N/A>'
+            Time    = 1.212904298
             Points  = '<N/A>'
             Type    = '<N/A>'
             Opt     = '<N/A>'
@@ -281,7 +270,7 @@ class RCT(RCT):
     def Get_5GNR_Params_System(self,header=0):
         if header != 1:
             error  = self.jav_Error()
-            ext    = self.Get_System_ErrorExt().replace('"','')
+            ext    = self.jav_Error()
             outStr = f'{error[0]:>4},{error[1]:10.10},{ext:10.10}'
         else:
             outStr  = 'ErrNo,ErrMsg,ExtError'
@@ -362,7 +351,6 @@ class RCT(RCT):
            units: dB """
         self.write(f'CONF:NRMM:MEAS:RFS:UMAR {pwr} DB')
 
-
     def Set_5GNR_BWP_Ch_DMRS_1stDMRSSym(self,TAP):
         """2 3"""
         self.write(f'CONF:NRMM:MEAS:CC{self.cc}:TAP {TAP}')
@@ -401,7 +389,7 @@ class RCT(RCT):
     def Set_5GNR_BWP_ResBlock(self, iRB, iRBO):
         ### RB = (CHBw * 0.95) / (SubSp * 12)
         self.write(f'CONF:NRMM:MEAS:CCAL:TXBW:SCSP {self.scs}')
-        self.write(f'CONF:NRMM:MEAS:CC{self.cc}:BWP BWP{self.BWP}, {self.scs}, NORM, {iRB}, {iRBO}')#SCS; NORM; RB; RBO
+        self.write(f'CONF:NRMM:MEAS:CC{self.cc}:BWP BWP{self.BWP}, {self.scs}, NORM, {iRB}, {iRBO}')    #SCS; NORM; RB; RBO
 
     # def Set_5GNR_BWP_ResBlockOffset(self,iRBO):
     #     self.write(f':SOUR1:BB:NR5G:UBWP:USER0:CELL{self.cc}:{self.sdir}:BWP0:RBOF {iRBO}')
@@ -487,10 +475,9 @@ class RCT(RCT):
 
     def Set_5GNR_TransPrecoding(self, sState):
         """ SC-FDMA or DFT-S-OFDM  """
-        sState = str(sState)
-        if   (sState == 'ON')  or (sState == "1"):
+        if sState in  (1, '1','ON'):
             self.write(f'CONF:NRMM:MEAS:CC{self.cc}:BWP:PUSC:DFTP BWP{self.BWP}, ON')
-        elif (sState == 'OFF') or (sState == "0"):
+        elif sState in  (0, '0','OFF'):
             self.write(f'CONF:NRMM:MEAS:CC{self.cc}:BWP:PUSC:DFTP BWP{self.BWP}, OFF')
         else:
             print('Error Set_5GNR_TransPrecoding')
