@@ -1,9 +1,4 @@
-# -*- coding: future_fstrings -*-
-######################################################################
-### Rohde & Schwarz Automation for demonstration use.
-### Purpose : Vector Signal Explorer Analog Demod Functions
-### Author  : Martin C Lim
-### Date    : 2018.04.27
+"""Vector Signal Explorer Analog Demod Functions"""
 from rssd.VSA.Common import VSA
 
 class VSA(VSA):
@@ -28,9 +23,13 @@ class VSA(VSA):
     #####################################################################
     ### ADemod Set
     #####################################################################
+    def Set_Adem_Coupling(self,sCouple):
+        """AC DC"""
+        self.write(f'SENS:ADEM:AF:COUP {sCouple}')
+
     def Set_Adem_dbw(self,iBW):
         """100Hz - MaxBW: Values is rounded up: 1;3;5;"""
-        self.write('SENS:BWID:DEM %d'%iBW)
+        self.write(f'SENS:BWID:DEM {iBW}')
 
     def Set_Adem_LPassStat(self,on):
         """LPass Filter: on"""
@@ -38,7 +37,7 @@ class VSA(VSA):
             self.write('SENSe:FILT:LPASS:STAT ON')
         elif (on == 'OFF') or (on == 0):
             self.write('SENSe:FILT:LPASS:STAT OFF')
-        else:
+        else:                                                   #pragma: no cover
             print('State not supported, please set ON or OFF')
 
     def Set_Adem_LPassAbsolute(self,sBW):
@@ -53,6 +52,22 @@ class VSA(VSA):
         """0 to 3MHz"""
         self.write(f'SENSe:FILT:LPASS:FREQ:MAN {fBW}')
 
+    def Set_Adem_PM_Unit(self,sUnit):
+        """DEG RAD"""
+        self.write(f'UNIT:ANGL {sUnit}')
+
+    def Set_Adem_PM_Scale(self,iRet):
+        """Degrees per reticle"""
+        self.write(f'DISP:TRAC1:Y:PDIV {iRet}')
+
+    def Set_Adem_PM_RefPos(self,iRefPos):
+        """PM Reference position: 0-100"""
+        self.write(f'DISP:TRAC:Y:SCAL:RPOS {iRefPos}PCT')
+
+    def Set_Adem_PM_RefVal(self,iRefVal):
+        """PM Reference Value: PM degrees"""
+        self.write(f'DISP:TRAC:Y:SCAL:RVAL {iRefVal}')
+
 #####################################################################
 ### Run if Main
 #####################################################################
