@@ -1,11 +1,5 @@
-# -*- coding: future_fstrings -*-
-#####################################################################
-### Rohde & Schwarz Automation for demonstration use.
-###
-### Purpose: Vector Signal Generator Custom Digital Modulation
-### Author : Martin C Lim
-### Date   : 2019.12.06
-#####################################################################
+"""Vector Signal Generator Custom Digital Modulation
+"""
 from rssd.VSG.Common import VSG             #pylint: disable=E0611,E0401
 
 class VSG(VSG):                             #pylint: disable=E0102
@@ -30,7 +24,7 @@ class VSG(VSG):                             #pylint: disable=E0102
             self.write(':SOUR1:BB:DM:STAT ON')
         elif (State == 0) or (State == 'OFF'):
             self.write(':SOUR1:BB:DM:STAT OFF')
-        else:
+        else:                                                   # pragma: no cover
             print('State not supported, please set ON or OFF')
 
 #####################################################################
