@@ -34,6 +34,7 @@ class VST(object):
         odata[0].append("Ch BW          ")
         odata[0].append("TransPrecoding ")
         odata[0].append("Phase Compensat")
+        odata[0].append("Phase Comp Freq")
         odata[0].append("====SS/PBCH====")
         odata[0].append("SubSpacing     ")
         odata[0].append("===User/BWP====")
@@ -76,6 +77,7 @@ class VST(object):
             odata[1].append(self.SMW.Get_5GNR_ChannelBW())
             odata[1].append(self.SMW.Get_5GNR_TransPrecoding())
             odata[1].append(self.SMW.Get_5GNR_PhaseCompensate())
+            odata[1].append(self.SMW.Get_5GNR_PhaseCompensate_Freq())
             odata[1].append("=SSB==")
             odata[1].append(self.SMW.Get_5GNR_SSB_SubSpace())
             odata[1].append("=User=")
@@ -122,6 +124,7 @@ class VST(object):
             odata[2].append(self.FSW.Get_5GNR_ChannelBW())
             odata[2].append(self.FSW.Get_5GNR_TransPrecoding())
             odata[2].append(self.FSW.Get_5GNR_PhaseCompensate())
+            odata[2].append(self.FSW.Get_5GNR_PhaseCompensate_Freq())
             odata[2].append("=SSB==")
             odata[2].append(self.FSW.Get_5GNR_SSB_SubSpace())
             odata[2].append("=User=")
