@@ -21,8 +21,14 @@ class jaTest(bus):                          #pylint: disable=R0205
     def read_raw(self):
         return b'1234567890'
 
+    def timeout(self, seconds):
+        pass
+
     def write_raw(self, SCPIstr):
         pass
 
     def write(self, SCPIstr):
         pass
+
+    def SCPI_error(self):
+        return ['0', 'No Error']
