@@ -41,8 +41,7 @@ meth = {0:'Autolvl()',
         5:'SetReflvl()',
         6:'K18()'
         }
-meth = {
-        1:'SetReflvl()',
+meth = {1:'SetReflvl()',
         0:'K18()',
         }
 asdf=len(meth)
@@ -110,7 +109,7 @@ VSA.Set_Trace_AvgCount(Avg)
 VSA.Set_Trace_Detector('RMS')
 VSA.Set_SweepOpt(SweMode)
 VSA.Set_SweepType(SweType)
-VSA.Set_YIG('OFF')
+VSA.Set_In_YIG('OFF')
 # VSA.Set_Trig1_Source('Ext')
 
 ##########################################################
@@ -129,7 +128,7 @@ for i in range(Repeat):
             eval(autoMeth)                                          # Dynamically call #pylint: disable=W0123
             ### <AUTOLEVEL> ###
 
-            tockA =  datetime.now()
+            tockA = datetime.now()
             VSA.write(':INIT:CONT OFF')                             # Single Sweep
             VSA.query(':INIT:IMM;*OPC?')                            # Take Sweep
             ACLR = VSA.query(':CALC:MARK:FUNC:POW:RES? MCAC')
@@ -140,7 +139,7 @@ for i in range(Repeat):
             ALTime = tockA - tick
             TotTime = tockB - tick
             OutStr = f'{VSA.Model},{i},{RBW},{MeasTim},{-50+pwr},{meth[autoMeth]},{ALTime.seconds:3d}.{ALTime.microseconds:06d},{TotTime.seconds:3d}.{TotTime.microseconds:06d},{AmpSet},{SwpParam},{ACLR},{Freq},{ChBW}'
-            OFile.write (OutStr)
+            OFile.write(OutStr)
 
 ##########################################################
 ### Cleanup Automation
