@@ -1,22 +1,18 @@
-##########################################################
-### Rohde & Schwarz Automation for demonstration use.
-###
-### Title  : Timing SCPI Commands Example
-### Author : mclim
-### Date   : 2018.05.24
-###  _____  _____   ____ _______ ____ _________     _______  ______
-### |  __ \|  __ \ / __ \__   __/ __ \__   __\ \   / /  __ \|  ____|
-### | |__) | |__) | |  | | | | | |  | | | |   \ \_/ /| |__) | |__
-### |  ___/|  _  /| |  | | | | | |  | | | |    \   / |  ___/|  __|
-### | |    | | \ \| |__| | | | | |__| | | |     | |  | |    | |____
-### |_|    |_|  \_\\____/  |_|  \____/  |_|     |_|  |_|    |______|
-###                         _            _           _
-###                        | |          | |         | |
-###             _   _ _ __ | |_ ___  ___| |_ ___  __| |
-###            | | | | '_ \| __/ _ \/ __| __/ _ \/ _` |
-###            | |_| | | | | ||  __/\__ \ ||  __/ (_| |
-###             \__,_|_| |_|\__\___||___/\__\___|\__,_|
-###
+"""
+VSA Memory & File functions
+ _____  _____   ____ _______ ____ _________     _______  ______
+|  __ ||  __ | / __ |__   __/ __ |__   __| |   / /  __ ||  ____|
+| |__) | |__) | |  | | | | | |  | | | |   | |_/ /| |__) | |__
+|  ___/|  _  /| |  | | | | | |  | | | |    |   / |  ___/|  __|
+| |    | | | || |__| | | | | |__| | | |     | |  | |    | |____
+|_|    |_|  |_||____/  |_|  |____/  |_|     |_|  |_|    |______|
+                        _            _           _
+                       | |          | |         | |
+            _   _ _ __ | |_ ___  ___| |_ ___  __| |
+           | | | | '_ || __/ _ |/ __| __/ _ |/ _` |
+           | |_| | | | | ||  __/|__ | ||  __/ (_| |
+            |__,_|_| |_||__|___||___/|__|___||__,_|
+"""
 ##########################################################
 ### User Entry
 ##########################################################
