@@ -1,33 +1,17 @@
-###############################################################################
-### Purpose: rssd.self.OTA.common.py driver test
-###              _   ___        __  _____         _   
-###             | | | \ \      / / |_   _|__  ___| |_ 
-###             | |_| |\ \ /\ / /    | |/ _ \/ __| __|
-###             |  _  | \ V  V /     | |  __/\__ \ |_ 
-###             |_| |_|  \_/\_/      |_|\___||___/\__|
-###             Please connect instrument prior 2 test
-###############################################################################
-### User Entry
-###############################################################################
-host = '192.168.1.50'                           #Get local machine name
-
-###############################################################################
-### Code Start
-###############################################################################
+"""rssd.self.OTA.common.py driver test"""
 import unittest
 from rssd.OTA.ATS1000 import OTA
 
+host = '192.168.1.50'                           #Get local machine name
+
 class TestGeneral(unittest.TestCase):
     def setUp(self):                            #run before each test
-        self.ATS1000 = OTA().jav_OpenTest(host)
+        self.ATS1000 = OTA().open(host, type='test')
 
     def tearDown(self):                         #Run after each test
-        self.assertEqual(self.ATS1000.jav_Error()[0],'0')
-        self.ATS1000.jav_Close()
+        self.assertEqual(self.ATS1000.SCPI_error(self)[0],'0')
+        self.ATS1000.close()
 
-###############################################################################
-### <Test>
-###############################################################################
     def test_OTA_Init(self):
         self.ATS1000.Init_Measurement()
 
@@ -38,9 +22,10 @@ class TestGeneral(unittest.TestCase):
         if self.ATS1000.connected : self.assertEqual(setVal, getVal)
         setVal = 10
         self.ATS1000.Set_AzimuthAngle(setVal)
-        # getVal = self.ATS1000.Get_AzimuthAngle()
+        getVal = self.ATS1000.Get_AzimuthAngle()
         getVal = self.ATS1000.Get_AzimuthRunning()
         if self.ATS1000.connected : self.assertEqual(setVal, getVal)
+        self.ATS1000.Set_AzimuthTrigger(5)
 
     def test_OTA_Elevation(self):
         setVal = 10
@@ -61,9 +46,6 @@ class TestGeneral(unittest.TestCase):
         self.ATS1000.Get_SysStat()
         self.ATS1000.Get_CxAngle()
 
-###############################################################################
-### </Test>
-###############################################################################
 if __name__ == '__main__':
 #coverage run -a -m unittest -b -v test_HW_OTA_Common
     suite = unittest.TestLoader().loadTestsFromTestCase(TestGeneral)
