@@ -1,33 +1,17 @@
-###############################################################################
-### Purpose: rssd.self.OTA.common.py driver test
-###              _   ___        __  _____         _   
-###             | | | \ \      / / |_   _|__  ___| |_ 
-###             | |_| |\ \ /\ / /    | |/ _ \/ __| __|
-###             |  _  | \ V  V /     | |  __/\__ \ |_ 
-###             |_| |_|  \_/\_/      |_|\___||___/\__|
-###             Please connect instrument prior 2 test
-###############################################################################
-### User Entry
-###############################################################################
-host = '192.168.1.50'                           #Get local machine name
-
-###############################################################################
-### Code Start
-###############################################################################
+"""rssd.self.OTA.common.py driver test"""
 import unittest
 from rssd.OTA.ATS1800 import OTA
 
+host = '192.168.1.50'                           #Get local machine name
+
 class TestGeneral(unittest.TestCase):
     def setUp(self):                            #run before each test
-        self.ATS1800 = OTA().jav_OpenTest(host)
+        self.ATS1800 = OTA().open(host, type='test')
 
     def tearDown(self):                         #Run after each test
-        self.assertEqual(self.ATS1800.jav_Error()[0],'0')
-        self.ATS1800.jav_Close()
+        self.assertEqual(self.ATS1800.SCPI_error(self)[0],'0')
+        self.ATS1800.close()
 
-###############################################################################
-### <Test>
-###############################################################################
     def test_OTA_Init(self):
         self.ATS1800.Init_Measurement()
 
@@ -60,9 +44,6 @@ class TestGeneral(unittest.TestCase):
     def test_OTA_SystemStat(self):
         self.ATS1800.Get_SysStat()
 
-###############################################################################
-### </Test>
-###############################################################################
 if __name__ == '__main__':
 #coverage run -a -m unittest -b -v test_HW_OTA_Common
     suite = unittest.TestLoader().loadTestsFromTestCase(TestGeneral)
