@@ -37,6 +37,21 @@ class TestGeneral(unittest.TestCase):
         getVal = self.FSW.Get_5GNR_Direction()
         if self.FSW.connected: self.assertEqual(getVal,'DL')
 
+    def test_FSW_5GNR_Ex_Meas_Multi_CC(self):
+        self.FSW.Init_5GNR_Meas('EVM')
+        # Configure setup
+        self.FSW.Set_5GNR_CellID(1)
+        self.FSW.Set_5GNR_SubFrameCount(2)
+        self.FSW.Set_5GNR_Result_View('ALL')        # Multi CC results
+        self.FSW.Set_5GNR_EVMUnit('DB')
+        self.FSW.Get_5GNR_Params_EVM()
+
+    def test_FSW_5GNR_Ex_SEM(self):
+        self.FSW.Init_5GNR_SEM()
+        self.FSW.Set_5GNR_SEM_Freq(20e9)
+        self.FSW.Set_5GNR_SEM_SubBlockNum(1)
+        self.FSW.Get_5GNR_SEM()
+
     def test_FSW_5GNR_FreqRange(self):
         self.FSW.Set_5GNR_Direction('UL')
         self.FSW.Set_5GNR_FreqRange('LOW')
@@ -70,7 +85,7 @@ class TestGeneral(unittest.TestCase):
         nullVal = self.FSW.Get_5GNR_BWP_Ch_ResBlockOffset()
         nullVal = self.FSW.Get_5GNR_BWP_Ch_SymbNum()
         nullVal = self.FSW.Get_5GNR_BWP_Ch_SymbOff()
-        # nullVal = self.FSW.Get_5GNR_BWP_Center()
+        if self.FSW.connected: nullVal = self.FSW.Get_5GNR_BWP_Center()
         ### "=DMRS="
         nullVal = self.FSW.Get_5GNR_BWP_Ch_DMRS_Config()
         nullVal = self.FSW.Get_5GNR_BWP_Ch_DMRS_Mapping()
@@ -95,6 +110,12 @@ class TestGeneral(unittest.TestCase):
         nullVal = self.FSW.Get_5GNR_BWP_Ch_PTRS_Pow()
         nullVal = self.FSW.Get_5GNR_BWP_Ch_PTRS_RE_Offset()
 
+    def test_FSW_5GNR_Get_Misc(self):
+        self.FSW.Get_5GNR_ACLR()
+        self.FSW.Get_5GNR_BWP_SlotNum()
+        self.FSW.Get_5GNR_CC_Offset()
+        self.FSW.Get_5GNR_Meas_ACLR()
+
     def test_FSW_5GNR_Get_UL(self):
         self.FSW.Set_5GNR_Direction('UL')
         nullVal = self.FSW.Get_5GNR_CC_Freq()
@@ -116,7 +137,7 @@ class TestGeneral(unittest.TestCase):
         nullVal = self.FSW.Get_5GNR_BWP_Ch_ResBlockOffset()
         nullVal = self.FSW.Get_5GNR_BWP_Ch_SymbNum()
         nullVal = self.FSW.Get_5GNR_BWP_Ch_SymbOff()
-        # nullVal = self.FSW.Get_5GNR_BWP_Center()
+        if self.FSW.connected: nullVal = self.FSW.Get_5GNR_BWP_Center()
         ### "=DMRS="
         nullVal = self.FSW.Get_5GNR_BWP_Ch_DMRS_Config()
         nullVal = self.FSW.Get_5GNR_BWP_Ch_DMRS_Mapping()
@@ -133,6 +154,13 @@ class TestGeneral(unittest.TestCase):
         nullVal = self.FSW.Get_5GNR_BWP_Ch_PTRS_Pow()
         nullVal = self.FSW.Get_5GNR_BWP_Ch_PTRS_RE_Offset()
 
+    def test_FSW_5GNR_InstrState(self):
+        self.FSW.Get_5GNR_TM_Cat()
+        self.FSW.Set_5GNR_TM('NR-FR1-TM1_1__FDD_15MHz_30kHz')
+        self.FSW.Set_5GNR_savesetting('test')
+        self.FSW.Set_5GNR_AllocFile('test')         #mmm
+        self.FSW.Set_5GNR_AllocFileSave('test')     #mmm
+
     def test_FSW_5GNR_Set_DL(self):
         self.FSW.Set_5GNR_Direction('DL')
         self.FSW.Set_5GNR_CC_Num(1)
@@ -146,10 +174,20 @@ class TestGeneral(unittest.TestCase):
         self.FSW.Set_5GNR_BWP_ResBlockOffset(0)
         self.FSW.Set_5GNR_BWP_Ch_ResBlock(66)
         self.FSW.Set_5GNR_BWP_Corset_ResBlock(66)
-        #self.FSW.Set_5GNR_BWP_Ch_ResBlockOffset(NR_RBO)
+        self.FSW.Set_5GNR_BWP_Ch_ResBlockOffset(0)
         self.FSW.Set_5GNR_BWP_Ch_Modulation('QPSK')
         # self.FSW.Set_5GNR_SSB()
 
+    def test_FSW_5GNR_Set_DMRS(self):
+        self.FSW.Set_5GNR_BWP_Ch_DMRS_1stDMRSSym(2)
+        self.FSW.Set_5GNR_BWP_Ch_DMRS_AddPosition(0)
+        self.FSW.Set_5GNR_BWP_Ch_DMRS_Config(1)
+        self.FSW.Set_5GNR_BWP_Ch_DMRS_Mapping('A')
+        self.FSW.Set_5GNR_BWP_Ch_DMRS_MSymbLen(1)
+        self.FSW.Set_5GNR_BWP_Ch_DMRS_RelPwr(0)
+        self.FSW.Set_5GNR_BWP_Ch_DMRS_SeqGenMeth('NICD')
+        self.FSW.Set_5GNR_BWP_Ch_DMRS_SeqGenSeed(0)
+
     def test_FSW_5GNR_Set_UL(self):
         self.FSW.Set_5GNR_Direction('UL')
         self.FSW.Set_5GNR_CC_Num(1)
@@ -162,9 +200,8 @@ class TestGeneral(unittest.TestCase):
         self.FSW.Set_5GNR_BWP_ResBlockOffset(0)
         self.FSW.Set_5GNR_BWP_Ch_ResBlock(66)
         self.FSW.Set_5GNR_BWP_Corset_ResBlock(66)
-        #self.FSW.Set_5GNR_BWP_Ch_ResBlockOffset(NR_RBO)
+        self.FSW.Set_5GNR_BWP_Ch_ResBlockOffset(0)
         self.FSW.Set_5GNR_BWP_Ch_Modulation('QPSK')
-        # self.FSW.Set_5GNR_SSB()
 
 ###############################################################################
 ### </Test>
